summaryrefslogtreecommitdiff
path: root/lisp/net
diff options
context:
space:
mode:
Diffstat (limited to 'lisp/net')
-rw-r--r--lisp/net/eudc.el2
-rw-r--r--lisp/net/newst-ticker.el2
-rw-r--r--lisp/net/newsticker.el2
-rw-r--r--lisp/net/rcirc.el8
4 files changed, 7 insertions, 7 deletions
diff --git a/lisp/net/eudc.el b/lisp/net/eudc.el
index 3f24a78cbbe..9bd01806d24 100644
--- a/lisp/net/eudc.el
+++ b/lisp/net/eudc.el
@@ -1213,7 +1213,7 @@ queries the server for the existing fields and displays a corresponding form."
;;; Load the options file
(if (and (not noninteractive)
(and (locate-library eudc-options-file)
- (progn (message "") t)) ; Remove modeline message
+ (progn (message "") t)) ; Remove mode line message
(not (featurep 'eudc-options-file)))
(load eudc-options-file))
diff --git a/lisp/net/newst-ticker.el b/lisp/net/newst-ticker.el
index e62dd284f7a..4b5ac3143d3 100644
--- a/lisp/net/newst-ticker.el
+++ b/lisp/net/newst-ticker.el
@@ -1,4 +1,4 @@
-;; newst-ticker.el --- modeline ticker for newsticker.
+;; newst-ticker.el --- mode line ticker for newsticker.
;; Copyright (C) 2003-2012 Free Software Foundation, Inc.
diff --git a/lisp/net/newsticker.el b/lisp/net/newsticker.el
index fc518c24843..5d673faf0db 100644
--- a/lisp/net/newsticker.el
+++ b/lisp/net/newsticker.el
@@ -103,7 +103,7 @@
;; -----
;; The command newsticker-show-news will display all available headlines in
;; a special buffer, called `*newsticker*'. It will also start the
-;; asynchronous download of headlines. The modeline in the `*newsticker*'
+;; asynchronous download of headlines. The mode line in the `*newsticker*'
;; buffer informs whenever new headlines have arrived. Clicking
;; mouse-button 2 or pressing RET in this buffer on a headline will call
;; browse-url to load the corresponding news story in your favorite web
diff --git a/lisp/net/rcirc.el b/lisp/net/rcirc.el
index 1898b3d074f..4bc99c1ef37 100644
--- a/lisp/net/rcirc.el
+++ b/lisp/net/rcirc.el
@@ -30,7 +30,7 @@
;; one-to-one communication.
;; Rcirc has simple defaults and clear and consistent behavior.
;; Message arrival timestamps, activity notification on the modeline,
;; message filling, nick completion, and keepalive pings are all
;; enabled by default, but can easily be adjusted or turned off. Each
;; discussion takes place in its own buffer and there is a single
@@ -394,7 +394,7 @@ will be killed."
"List of buffers with unviewed activity.")
(defvar rcirc-activity-string ""
- "String displayed in modeline representing `rcirc-activity'.")
+ "String displayed in mode line representing `rcirc-activity'.")
(put 'rcirc-activity-string 'risky-local-variable t)
(defvar rcirc-server-buffer nil
@@ -1599,7 +1599,7 @@ record activity."
(buffer-disable-undo)
(buffer-enable-undo))
;; record modeline activity
(when (and activity
(not rcirc-ignore-buffer-activity-flag)
(not (and rcirc-dim-nicks sender
@@ -2003,7 +2003,7 @@ activity. Only run if the buffer is not visible and
buffers ","))
(defun rcirc-short-buffer-name (buffer)
- "Return a short name for BUFFER to use in the modeline indicator."
+ "Return a short name for BUFFER to use in the mode line indicator."
(with-current-buffer buffer
(or rcirc-short-buffer-name (buffer-name))))
@@ -30,7 +30,7 @@
;; one-to-one communication.
;; Rcirc has simple defaults and clear and consistent behavior.
-;; Message arrival timestamps, activity notification on the modeline,
+;; Message arrival timestamps, activity notification on the mode line,
;; message filling, nick completion, and keepalive pings are all
;; enabled by default, but can easily be adjusted or turned off. Each
@@ -1599,7 +1599,7 @@ record activity."
(buffer-disable-undo)
(buffer-enable-undo))
- ;; record modeline activity
+ ;; record mode line activity
(when (and activity
(not rcirc-ignore-buffer-activity-flag)